# Type-annotated and linted Python interface for Gmsh

## Development

Install a version of Python 3.12 in your environment.
For example, if you manage python versions with `uv`, then you may prepare
the environment by prefixing commands with `uv run --no-project --python 312`.

Prepare a development environment with `make`.

Run tests with `make test`.

Run static analysis with `make lint`.
